@@ -1,17 +1,18 @@
 package App::ListRevDeps;
 
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.13'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any qw($log);
+use Log::Any::IfLOG qw($log);
 
 our %SPEC;
 require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(list_prereqs);
 
-our $VERSION = '0.12'; # VERSION
-
 $SPEC{list_rev_deps} = {
     v => 1.1,
     summary => 'List reverse dependencies of a Perl module',
@@ -157,7 +158,7 @@ sub list_rev_deps {
 }
 
 1;
-#ABSTRACT: List reverse dependencies of a Perl module
+# ABSTRACT: List reverse dependencies of a Perl module
 
 __END__
 
@@ -171,7 +172,7 @@ App::ListRevDeps - List reverse dependencies of a Perl module
 
 =head1 VERSION
 
-This document describes version 0.12 of App::ListRevDeps (from Perl distribution App-ListRevDeps), released on 2014-09-16.
+This document describes version 0.13 of App::ListRevDeps (from Perl distribution App-ListRevDeps), released on 2015-08-17.
 
 =head1 SYNOPSIS
 
@@ -187,7 +188,7 @@ caches results for 24 hours.
 
 =head2 list_rev_deps(%args) -> [status, msg, result, meta]
 
-List reverse dependencies of a Perl module.
+{en_US List reverse dependencies of a Perl module}.
 
 Arguments ('*' denotes required arguments):
 
@@ -195,28 +196,26 @@ Arguments ('*' denotes required arguments):
 
 =item * B<cache> => I<bool> (default: 1)
 
-Whether to cache API results for some time, for performance.
+{en_US Whether to cache API results for some time, for performance}.
 
 =item * B<exclude_re> => I<str>
 
-Specify dist pattern to exclude.
+{en_US Specify dist pattern to exclude}.
 
 =item * B<level> => I<int> (default: 1)
 
-Specify how many levels up to check (-1 means unlimited).
+{en_US Specify how many levels up to check (-1 means unlimited)}.
 
 =item * B<module>* => I<array>
 
-Perl module(s) to check.
+{en_US Perl module(s) to check}.
 
 =item * B<raw> => I<bool> (default: 0)
 
-Return raw result.
+{en_US Return raw result}.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -226,7 +225,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 =head1 ENVIRONMENT
 
@@ -240,6 +239,10 @@ If enabled, will log raw API response (at trace level).
 
 =head1 SEE ALSO
 
+L<App::lcpan> indexes CPAN Meta information from releases in your local CPAN
+mirror, and allows you to query dependencies and reverse dependencies
+information from the index.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/App-ListRevDeps>.
@@ -262,7 +265,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
